AutoGrow Plugin - CKEditor Sample

# CKEditor Sample

In this sample the AutoGrow plugin is available. It makes the editor grow to fit the size of the content.

With default configuration:
<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>

With maximum height set to 400:
<p>This is some <strong>sample text</strong>. You are using <a href="http://ckeditor.com/">CKEditor</a>.</p>